@@ -43,6 +43,7 @@ AST_UNOP_MAP = {
     ast.Invert: Symbol._reserved("~"),
 }
 
+
 def parse(source: str | Callable, squeeze: bool = True) -> Expr | Symbol:
     """
     Convert Python code string into Expr/Symbol objects.
@@ -54,23 +55,26 @@ def parse(source: str | Callable, squeeze: bool = True) -> Expr | Symbol:
         ast_object = body[0]
     else:
         ast_object = body
-    
+
     out = from_ast(ast_object)
     if not squeeze and len(body) == 1:
         out = Expr(Head.block, [out])
     return out
 
+
 @singledispatch
 def from_ast(ast_object: ast.AST | list | NoneType):
     """
     Convert AST object to macro-kit object.
-    """    
+    """
     raise NotImplementedError(f"AST type {type(ast_object)} cannot be converted now.")
 
+
 @from_ast.register
 def _(ast_object: NoneType):
     return None
 
+
 @from_ast.register
 def _(ast_object: ast.Expr):
     return from_ast(ast_object.value)
@@ -80,19 +84,19 @@ if sys.version_info <= (3, 7):
     @from_ast.register
     def _(ast_object: ast.Num):
         return symbol(ast_object.n)
-    
+
     @from_ast.register
     def _(ast_object: ast.Str):
         return symbol(ast_object.s)
-    
+
     @from_ast.register
     def _(ast_object: ast.NameConstant):
         return symbol(ast_object.n)
-    
+
     @from_ast.register
     def _(ast_object: ast.Bytes):
         return symbol(ast_object.s)
-    
+
     @from_ast.register
     def _(ast_object: ast.Ellipsis):
         return symbol(ast_object.s)
@@ -102,6 +106,7 @@ else:
     def _(ast_object: ast.Constant):
         return symbol(ast_object.value)
 
+
 @from_ast.register
 def _(ast_object: ast.Name):
     name = ast_object.id
@@ -109,13 +114,17 @@ def _(ast_object: ast.Name):
         return Symbol._module_map[name]
     return Symbol(ast_object.id)
 
+
 @from_ast.register
 def _(ast_object: ast.Expr):
     return from_ast(ast_object.value)
 
+
 @from_ast.register
 def _(ast_object: ast.UnaryOp):
-    return Expr(Head.unop, [AST_UNOP_MAP[type(ast_object.op)], from_ast(ast_object.operand)])
+    return Expr(Head.unop, [AST_UNOP_MAP[type(ast_object.op)],
+                            from_ast(ast_object.operand)])
+
 
 @from_ast.register
 def _(ast_object: ast.AugAssign):
@@ -123,7 +132,8 @@ def _(ast_object: ast.AugAssign):
     op = AST_BINOP_MAP[type(ast_object.op)]
     value = from_ast(ast_object.value)
     return Expr(Head.aug, [op, target, value])
-    
+
+
 @from_ast.register
 def _(ast_object: ast.Call):
     head = Head.call
@@ -131,6 +141,7 @@ def _(ast_object: ast.Call):
         [Expr(Head.kw, [Symbol(k.arg), from_ast(k.value)]) for k in ast_object.keywords]
     return Expr(head, args)
 
+
 @from_ast.register
 def _(ast_object: ast.Assign):
     head = Head.assign
@@ -141,47 +152,58 @@ def _(ast_object: ast.Assign):
     args = [target, from_ast(ast_object.value)]
     return Expr(head, args)
 
+
 @from_ast.register
 def _(ast_object: ast.Attribute):
     head = Head.getattr
     args = [from_ast(ast_object.value), Symbol(ast_object.attr)]
     return Expr(head, args)
 
+
 @from_ast.register
 def _(ast_object: ast.Subscript):
     head = Head.getitem
     args = [from_ast(ast_object.value), from_ast(ast_object.slice)]
     return Expr(head, args)
 
+
 @from_ast.register
 def _(ast_object: ast.List):
     return symbol([from_ast(k) for k in ast_object.elts])
 
+
 @from_ast.register
 def _(ast_object: ast.Tuple):
     return symbol(tuple(from_ast(k) for k in ast_object.elts))
 
+
 @from_ast.register
 def _(ast_object: ast.Set):
     return symbol(set(from_ast(k) for k in ast_object.elts))
 
+
 @from_ast.register
 def _(ast_object: ast.Slice):
-    return symbol(slice(from_ast(ast_object.lower), 
+    return symbol(slice(from_ast(ast_object.lower),
                         from_ast(ast_object.upper),
                         from_ast(ast_object.step))
                   )
 
+
 @from_ast.register
 def _(ast_object: ast.Dict):
-    return symbol({from_ast(k): from_ast(v) for k, v in zip(ast_object.keys, ast_object.values)})
+    return symbol({from_ast(k): from_ast(v)
+                   for k, v in zip(ast_object.keys, ast_object.values)})
+
 
 @from_ast.register
 def _(ast_object: ast.BinOp):
     head = Head.binop
-    args = [AST_BINOP_MAP[type(ast_object.op)], from_ast(ast_object.left), from_ast(ast_object.right)]
+    args = [AST_BINOP_MAP[type(ast_object.op)], from_ast(
+        ast_object.left), from_ast(ast_object.right)]
     return Expr(head, args)
 
+
 @from_ast.register
 def _(ast_object: ast.BoolOp):
     head = Head.binop
@@ -189,12 +211,14 @@ def _(ast_object: ast.BoolOp):
     args = nest_binop(op, ast_object.values)
     return Expr(head, args)
 
+
 @from_ast.register
 def _(ast_object: ast.Compare):
     head = Head.binop
     args = nest_compare(ast_object.ops, [ast_object.left] + ast_object.comparators)
     return Expr(head, args)
 
+
 @from_ast.register
 def _(ast_object: ast.If):
     head = Head.if_
@@ -203,15 +227,18 @@ def _(ast_object: ast.If):
             from_ast(ast_object.orelse)]
     return Expr(head, args)
 
+
 @from_ast.register
 def _(ast_object: ast.For):
     head = Head.for_
-    top = Expr(Head.binop, [Symbol.var("in"), from_ast(ast_object.target), from_ast(ast_object.iter)])
+    top = Expr(Head.binop, [Symbol.var("in"), from_ast(
+        ast_object.target), from_ast(ast_object.iter)])
     block = from_ast(ast_object.body)
     if ast_object.orelse:
         raise ValueError("'else' block is not supported yet")
     return Expr(head, [top, block])
 
+
 @from_ast.register
 def _(ast_object: ast.While):
     head = Head.while_
@@ -221,12 +248,14 @@ def _(ast_object: ast.While):
         raise ValueError("'else' block is not supported yet")
     return Expr(head, [test, block])
 
+
 @from_ast.register
 def _(ast_object: list):
     head = Head.block
     args = [from_ast(k) for k in ast_object]
     return Expr(head, args)
 
+
 @from_ast.register
 def _(ast_object: ast.FunctionDef):
     # TODO: positional only etc. are not supported
@@ -235,9 +264,11 @@ def _(ast_object: ast.FunctionDef):
     fargs = ast_object.args
     nargs = len(fargs.args) - len(fargs.defaults)
     args = [from_ast(k) for k in fargs.args[:nargs]]
-    kwargs = [Expr(Head.kw, [from_ast(k), from_ast(v)]) 
+    kwargs = [Expr(Head.kw, [from_ast(k), from_ast(v)])
               for k, v in zip(fargs.args[nargs:], fargs.defaults)]
-    return Expr(head, [Expr(Head.call, [fname] + args + kwargs), from_ast(ast_object.body)])
+    return Expr(head, [Expr(Head.call, [fname] + args + kwargs),
+                       from_ast(ast_object.body)])
+
 
 @from_ast.register
 def _(ast_object: ast.arg):
@@ -247,55 +278,63 @@ def _(ast_object: ast.arg):
     else:
         return Symbol(ast_object.arg)
 
+
 @from_ast.register
 def _(ast_object: ast.AnnAssign):
     head = Head.assign
     target = from_ast(ast_object.target)
-    args = [Expr(Head.annotate, [target, from_ast(ast_object.annotation)]), 
+    args = [Expr(Head.annotate, [target, from_ast(ast_object.annotation)]),
             from_ast(ast_object.value)]
     return Expr(head, args)
 
+
 @from_ast.register
 def _(ast_object: ast.Pass):
     return Symbol.var("pass")
 
+
 @from_ast.register
 def _(ast_object: ast.Break):
     return Symbol.var("break")
 
+
 @from_ast.register
 def _(ast_object: ast.Continue):
     return Symbol.var("continue")
 
+
 @from_ast.register
 def _(ast_object: ast.Raise):
     exc = ast_object.exc
     if ast_object.cause:
         raise ValueError("'raise XX from YY' is not supported yet")
     return Expr(Head.raise_, [from_ast(exc)])
-    
+
+
 @from_ast.register
 def _(ast_object: ast.Return):
     head = Head.return_
     args = [from_ast(ast_object.value)]
     return Expr(head, args)
 
+
 def nest_binop(op, values: list[ast.AST]):
     if len(values) == 2:
-        return [op, 
-                from_ast(values[0]), 
+        return [op,
+                from_ast(values[0]),
                 from_ast(values[1])]
     else:
-        return [op, 
-                from_ast(values[0]), 
+        return [op,
+                from_ast(values[0]),
                 Expr(Head.binop, nest_binop(op, values[1:]))]
 
+
 def nest_compare(ops: list[ast.AST], values: list[ast.AST]):
     if len(ops) == 1:
         return [AST_BINOP_MAP[type(ops[0])],
-                from_ast(values[0]), 
+                from_ast(values[0]),
                 from_ast(values[1])]
     else:
-        return [AST_BINOP_MAP[type(ops[0])], 
-                from_ast(values[0]), 
-                Expr(Head.binop, nest_compare(ops[1:], values[1:]))]
\ No newline at end of file
+        return [AST_BINOP_MAP[type(ops[0])],
+                from_ast(values[0]),
+                Expr(Head.binop, nest_compare(ops[1:], values[1:]))]
